from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, File, Directory, Boolean

Metaxa2_X_V0_1_0 = CommandToolBuilder(tool="metaxa2_x", base_command=["metaxa2_x"], inputs=[ToolInput(tag="in_dna_fasta_input", input_type=String(optional=True), prefix="-i", doc=InputDocumentation(doc=": DNA FASTA input file to investigate")), ToolInput(tag="in_base_names_output", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc=": Base for the names of output file(s)")), ToolInput(tag="in_path_directory_hmmprofile", input_type=String(optional=True), prefix="-p", doc=InputDocumentation(doc=": A path to a directory of HMM-profile collections representing rRNA conserved regions, default is in the same directory as metaxa itself")), ToolInput(tag="in_hmm_search", input_type=File(optional=True), prefix="--hmmsearch", doc=InputDocumentation(doc=": If the hmmsearch has already been performed, this option can be used as the base for the hmmsearch output files, and the hmmsearch step will be skipped. Overrides the -o option, while a DNA FASTA file must still be supplied!")), ToolInput(tag="in_date", input_type=Directory(optional=True), prefix="--date", doc=InputDocumentation(doc=": Adds a date and time stamp to the output directory, off (F) by default")), ToolInput(tag="in_reset", input_type=String(optional=True), prefix="--reset", doc=InputDocumentation(doc=": Rebuilds the HMM database. Useful if HMMER has been updated or searches seem to fail mysteriously, off (F) by default")), ToolInput(tag="in_profile_set_use", input_type=String(optional=True), prefix="-t", doc=InputDocumentation(doc=": Profile set to use for the search (comma-separated), default is all")), ToolInput(tag="in_specifies_barcoding_gene", input_type=String(optional=True), prefix="-g", doc=InputDocumentation(doc=": Specifies the barcoding gene Metaxa should look for, default is ssu")), ToolInput(tag="in_mode", input_type=String(optional=True), prefix="--mode", doc=InputDocumentation(doc=": Controls the Metaxa2 operating mode, default = metagenome")), ToolInput(tag="in_domain_evalue_cutoff", input_type=String(optional=True), prefix="-E", doc=InputDocumentation(doc=": Domain E-value cutoff for a sequence to be included in the output, default = 1")), ToolInput(tag="in_domain_score_cutoff", input_type=String(optional=True), prefix="-S", doc=InputDocumentation(doc=": Domain score cutoff for a sequence to be included in the output, default = 12")), ToolInput(tag="in_minimal_number_match", input_type=String(optional=True), prefix="-N", doc=InputDocumentation(doc=": The minimal number of domains that must match a sequence before it is included, default = 2")), ToolInput(tag="in_selection_priority", input_type=String(optional=True), prefix="--selection_priority", doc=InputDocumentation(doc=": Selects what will be of highest priority when determining the origin of the sequence, default is sum")), ToolInput(tag="in_search_eval", input_type=String(optional=True), prefix="--search_eval", doc=InputDocumentation(doc=": The E-value cutoff used in the HMMER search, high numbers may slow down the process, cannot be used with the --search_score option, default is to use score cutoff, not E-value")), ToolInput(tag="in_search_score", input_type=String(optional=True), prefix="--search_score", doc=InputDocumentation(doc=": The score cutoff used in the HMMER search, low numbers may slow down the process, cannot be used with the --search_eval option, default = 0")), ToolInput(tag="in_allow_single_domain", input_type=String(optional=True), prefix="--allow_single_domain", doc=InputDocumentation(doc=": Allow inclusion of sequences that only find a single domain, given that they meet the given E-value and score thresholds, on with parameters 1e-10,0 by default")), ToolInput(tag="in_allow_reorder", input_type=String(optional=True), prefix="--allow_reorder", doc=InputDocumentation(doc=": Allows profiles to be in the wrong order on extracted sequences, on (T) by default")), ToolInput(tag="in_complement", input_type=String(optional=True), prefix="--complement", doc=InputDocumentation(doc=": Checks both DNA strands against the database, creating reverse complements, on (T) by default")), ToolInput(tag="in_cpu", input_type=String(optional=True), prefix="--cpu", doc=InputDocumentation(doc=": the number of CPU threads to use, default is 1")), ToolInput(tag="in_multi_thread", input_type=String(optional=True), prefix="--multi_thread", doc=InputDocumentation(doc=": Multi-thread the HMMER-search, on (T) if number of CPUs (--cpu option > 1), else off (F) by default")), ToolInput(tag="in_heuristics", input_type=String(optional=True), prefix="--heuristics", doc=InputDocumentation(doc=": Selects whether to use HMMER's heuristic filtering, on (T) by default")), ToolInput(tag="in_summary", input_type=String(optional=True), prefix="--summary", doc=InputDocumentation(doc=": Summary of results output, on (T) by default")), ToolInput(tag="in_graphical", input_type=String(optional=True), prefix="--graphical", doc=InputDocumentation(doc=": 'Graphical' output, on (T) by default")), ToolInput(tag="in_fast_a", input_type=String(optional=True), prefix="--fasta", doc=InputDocumentation(doc=": FASTA-format output of extracted rRNA sequences, on (T) by default")), ToolInput(tag="in_table", input_type=String(optional=True), prefix="--table", doc=InputDocumentation(doc=": Table format output of sequences containing probable rRNAs, off (F) by default")), ToolInput(tag="in_not_found", input_type=String(optional=True), prefix="--not_found", doc=InputDocumentation(doc=": Saves a list of non-found entries, off (F) by default")), ToolInput(tag="in_truncate", input_type=String(optional=True), prefix="--truncate", doc=InputDocumentation(doc=": Truncates the FASTA output to only contain the putative rRNA sequence found, on (T) by default")), ToolInput(tag="in_silent", input_type=String(optional=True), prefix="--silent", doc=InputDocumentation(doc=": Supresses printing progress info to stderr, off (F) by default")), ToolInput(tag="in_graph_scale", input_type=String(optional=True), prefix="--graph_scale", doc=InputDocumentation(doc=": Sets the scale of the graph output, if value is zero, a percentage view is shown, default = 0")), ToolInput(tag="in_save_raw", input_type=String(optional=True), prefix="--save_raw", doc=InputDocumentation(doc=": Saves all raw data for searches etc. instead of removing it on finish, off (F) by default")), ToolInput(tag="in_help", input_type=Boolean(optional=True), prefix="--help", doc=InputDocumentation(doc=": displays this help message")), ToolInput(tag="in_bugs", input_type=Boolean(optional=True), prefix="--bugs", doc=InputDocumentation(doc=": displays the bug fixes and known bugs in this version of Metaxa")), ToolInput(tag="in_license", input_type=Boolean(optional=True), prefix="--license", doc=InputDocumentation(doc=": displays licensing information"))], outputs=[ToolOutput(tag="out_base_names_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_base_names_output", type_hint=File()), doc=OutputDocumentation(doc=": Base for the names of output file(s)")), ToolOutput(tag="out_hmm_search", output_type=File(optional=True), selector=InputSelector(input_to_select="in_hmm_search", type_hint=File()), doc=OutputDocumentation(doc=": If the hmmsearch has already been performed, this option can be used as the base for the hmmsearch output files, and the hmmsearch step will be skipped. Overrides the -o option, while a DNA FASTA file must still be supplied!")), ToolOutput(tag="out_date", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_date", type_hint=File()), doc=OutputDocumentation(doc=": Adds a date and time stamp to the output directory, off (F) by default"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Metaxa2_X_V0_1_0().translate("wdl", allow_empty_container=True)

